<?php
namespace Teknisa\PLA\Modules\Parametros\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\Report\ReportService;

class Pla03500Report extends \Zeedhi\Framework\Controller\Report {

    protected $reportService;
    protected $qr2Strategy;
    protected $environment;
    protected $crudService;

    public function __construct($reportService, $qr2Strategy, $environment, $crudService) {
        $this->reportService = $reportService;
        $this->qr2Strategy = $qr2Strategy;
        $this->environment = $environment;
        $this->crudService = $crudService;
    }

    protected $reportMapping = array (
    'PLA03500' =>
        array (
            'strategy' => 'QR2',
            'parameterMapping' =>
            array (
                'CDFILIAL'      => 'P_CDFILIAL',
                'L_SERVFILI'    => 'P_CDSERVICO',
                'CDPRATOINI'    => 'P_CDPRATOINI',
                'CDPRATOFIN'    => 'P_CDPRATOFIN'
            )
        )
    );

    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $this->qr2Strategy->setQr2Type($row['QR2TYPE']);

        if ($row['L_SERVFILI'] == 'T') {
            $row['L_SERVFILI'] = $this->getServicos($row['CDFILIAL']);
        }
    }

    private function getServicos($filial) {
        $conditions = array(
            array(
                "columnName" => "CDFILIAL",
                "operator" => "=",
                "value" => $filial
            ),
            array(
                "columnName" => "IDTIPOSERV",
                "operator" => "=",
                "value" => "N"
            ),
            array(
                "columnName" => "NRORG",
                "operator" => "=",
                "value" => $this->environment->getNrOrg()
            )
        );
        $dataSet = $this->crudService->getFilteredDataSet("servico", $conditions);
        $rows = $dataSet->getRows();
        $servicos = array();
        foreach ($rows as $servico) {
            array_push($servicos, $servico['CDSERVFILI']);
        }
        return implode('_', $servicos);
    }
}